sub vcl_recv {
  // Initialize the variables in use throughout this VCL.
  if (req.restarts == 0) {
    /**
     * The X-Authcache-Allow variable is set to 1 or 0 depending whether
     * caching is allowed or not. You may include site-specific policies by
     * modifying 02_policy.vcl.
     */
    unset req.http.X-Authcache-Allow;

    /**
     * The X-Authcache-Do-ESI variable is set to 1 or 0 depending whether
     * ESI processing should be allowed or not. You may include site-specific
     * policies by modifying 02_policy.vcl.
     */
    unset req.http.X-Authcache-Do-ESI;

    /**
     * The X-Authcache-Key header should be set on each request sent to the
     * backend. If this header is empty or missing on a request, the response
     * is not cached. Note that the header musst be set even on anonymous
     * traffic, otherwise it will not be cached.
     */
    unset req.http.X-Authcache-Key;

    /**
     * The default vcl_recv proceeds to pass when cookies are present on the
     * request. When authcache indicates that a page might be cacheble for a
     * logged in user (i.e. the X-Authcache-Key header is present), it is
     * necessary to clear the Cookies header in order to prevent the default
     * VCL to cancel caching. However the cookies need to be restored before a
     * request is sent on to the backend. The X-Cookie-Backup variable is used
     * to tunnel the cookies through the default vcl_recv so that they can be
     * restored within vcl_hash.
     */
    unset req.http.X-Cookie-Backup;

    /**
     * Before fulfilling a request, the authcache-key needs to be retrieved
     * either from the cache or the backend. When this variable is set, the
     * request is within the key-retrieval phase.
     */
    unset req.http.X-Authcache-Get-Key;

    /**
     * The path on the backend where the authcache-key is retrieved from.
     */
    set req.http.X-Authcache-Get-Key-URL = "/authcache-varnish-get-key";

    /**
     * During the key-retrieval phase this variable is set to the URL the
     * client originally requested.
     */
    unset req.http.X-Original-URL;
  }
}
